@@ -13,19 +13,18 @@
 # ----------------------------------------------------------------------
 
 package Text::BibTeX;
-use Text::BibTeX::Name;
-use Text::BibTeX::NameFormat;
 
 use 5.008001;                          # needed for Text::BibTeX::Entry
 
 use strict;
+use UNIVERSAL qw(isa can);              # for 'check_class' subroutine
 use Carp;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.76_02';
+our $VERSION='0.40';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -46,53 +45,9 @@ our $VERSION='0.76_02';
               @{$EXPORT_TAGS{'nodetypes'}},
               @{$EXPORT_TAGS{'nameparts'}},
               @{$EXPORT_TAGS{'joinmethods'}},
-              'check_class', 'display_list' );
+              'check_class', 'display_list');
 @EXPORT = @{$EXPORT_TAGS{'metatypes'}};
 
-use Encode 'encode', 'decode';
-use Unicode::Normalize;
-
-
-sub _process_result {
-  no strict 'refs';
-  my ( $self, $result, $encoding, $norm ) = @_;
-
-  $norm ||= "NFC"; # best to force it here.
-  my $normsub = \&{"$norm"}; # symbolic ref
-    if ( $encoding eq "utf-8" ) {
-        if ( utf8::is_utf8($result) ) {
-            return $normsub->($result);
-        }
-        else {
-            return $normsub->( decode( $encoding, $result ) );
-        }
-    }
-    else { return $result; }
-
-}
-
-sub _process_argument {
-    my ( $self, $value, $encoding ) = @_;
-
-     if ( $encoding eq "utf-8" && utf8::is_utf8($value)) {
-         return encode( $encoding, $value );
-     }
-     else {
-        return $value;
-    }
-}
-
-sub split_list {
-    my ( $field, $delim, $filename, $line, $desc, $opts ) = @_;
-    $opts                  ||= {};
-    $opts->{binmode}       ||= 'bytes';
-    $opts->{normalization} ||= 'NFC';
-    return
-        map { Text::BibTeX->_process_result( $_, $opts->{binmode}, $opts->{normalization} ) }
-        Text::BibTeX::isplit_list( $field, $delim, $filename, $line, $desc );
-
-}
-
 =head1 NAME
 
 Text::BibTeX - interface to read and parse BibTeX files
@@ -101,10 +56,10 @@ Text::BibTeX - interface to read and parse BibTeX files
 
    use Text::BibTeX;
 
-   $bibfile = Text::BibTeX::File->new("foo.bib");
-   $newfile = Text::BibTeX::File->new(">newfoo.bib");
+   $bibfile = new Text::BibTeX::File "foo.bib";
+   $newfile = new Text::BibTeX::File ">newfoo.bib";
 
-   while ($entry = Text::BibTeX::Entry->($bibfile))
+   while ($entry = new Text::BibTeX::Entry $bibfile)
    {
       next unless $entry->parse_ok;
 
@@ -286,12 +241,6 @@ bootstrap Text::BibTeX;
 initialize();                            # these are both XS functions
 END { &cleanup; }
 
-# This can't go in a BEGIN because of the .XS bootstrapping mechanism
-for my $month (qw.january february march april may june
-             july august september october november december.) {
-    add_macro_text(substr($month, 0, 3), ucfirst($month));
-}
-
 
 =head1 EXPORTS
 
@@ -446,11 +395,11 @@ sub bibloop (&$;$)
    my $file;
    while ($file = shift @$files)
    {
-      my $bib = Text::BibTeX::File->new($file);
+      my $bib = new Text::BibTeX::File $file;
       
       while (! $bib->eof())
       {
-         my $entry = Text::BibTeX::Entry->new($bib);
+         my $entry = new Text::BibTeX::Entry $bib;
          next unless $entry->parse_ok;
 
          my $result = &$action ($entry);
@@ -521,7 +470,7 @@ sub check_class
       }
    }
 
-   if ($superclass && ! $package->isa($superclass))
+   if ($superclass && ! isa ($package, $superclass))
    {
       die "Text::BibTeX::Structure: $description \"$package\" " .
           "improperly defined: ! isa ($superclass)\n";
@@ -530,7 +479,7 @@ sub check_class
    my $method;
    for $method (@$methods)
    {
-      unless ($package->can($method))
+      unless (can ($package, $method))
       {
          die "Text::BibTeX::Structure: $description \"$package\" " .
              "improperly defined: no method \"$method\"\n";
@@ -623,7 +572,7 @@ of it as appropriate.  They're just mentioned here for completeness.
 
 =over 4
 
-=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION [, OPTS]]]])
+=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
 
 Splits a string on a fixed delimiter according to the BibTeX rules for
 splitting up lists of names.  With BibTeX, the delimiter is hard-coded
@@ -632,23 +581,7 @@ STRING are considered delimiters if they are at brace-depth zero,
 surrounded by whitespace, and not at the beginning or end of STRING; the
 comparison is case-insensitive.  See L<bt_split_names> for full details
 of how splitting is done (it's I<not> the same as Perl's C<split>
-function). OPTS is a hash ref of the same binmode and normalization
-arguments as with, e.g. Text::BibTeX::File->open(). split_list calls isplit_list()
-internally but handles UTF-8 conversion and normalization, if requested.
-
-Returns the list of strings resulting from splitting STRING on DELIM.
-
-=item isplit_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
-
-Splits a string on a fixed delimiter according to the BibTeX rules for
-splitting up lists of names.  With BibTeX, the delimiter is hard-coded
-as C<"and">; here, you can supply any string.  Instances of DELIM in
-STRING are considered delimiters if they are at brace-depth zero,
-surrounded by whitespace, and not at the beginning or end of STRING; the
-comparison is case-insensitive.  See L<bt_split_names> for full details
-of how splitting is done (it's I<not> the same as Perl's C<split>
-function). This function returns bytes. Use Text::BibTeX::split_list to specify
-the same binmode and normalization arguments as with, e.g. Text::BibTeX::File->open()
+function).
 
 Returns the list of strings resulting from splitting STRING on DELIM.
 
@@ -721,8 +654,7 @@ takes no action.
 
 =item delete_all_macros ()
 
-Deletes all macros from the macro table, even the predefined month
-names.
+Deletes all macros from the macro table.
 
 =item macro_length (MACRO)
 
@@ -798,6 +730,30 @@ Copyright (c) 1997-2000 by Gregory P. Ward.  All rights reserved.  This file
 is part of the Text::BibTeX library.  This library is free software; you
 may redistribute it and/or modify it under the same terms as Perl itself.
 
+=head1 AVAILABILITY
+
+The btOOL home page, where you can get up-to-date information about
+C<Text::BibTeX> (and download the latest version) is
+
+   http://starship.python.net/~gward/btOOL/
+
+You will also find the latest version of B<btparse>, the C library
+underlying C<Text::BibTeX>, there.  B<btparse> is needed to build
+C<Text::BibTeX>, and must be downloaded separately.
+
+Both libraries are also available on CTAN (the Comprehensive TeX Archive
+Network, C<http://www.ctan.org/tex-archive/>) and CPAN (the Comprehensive
+Perl Archive Network, C<http://www.cpan.org/>).  Look in
+F<biblio/bibtex/utils/btOOL/> on CTAN, and F<authors/Greg_Ward/> on
+CPAN.  For example,
+
+   http://www.ctan.org/tex-archive/biblio/bibtex/utils/btOOL/
+   http://www.cpan.org/authors/Greg_Ward
+
+will both get you to the latest version of C<Text::BibTeX> and B<btparse>
+-- but of course, you should always access busy sites like CTAN and CPAN
+through a mirror.
+
 =cut
 
 1;
